@@ -57,7 +57,7 @@
 /* #undef HAVE_HALIDE */
 
 /* Vulkan support */
-#define HAVE_VULKAN
+/* #undef HAVE_VULKAN */
 
 /* Define to 1 if you have the <inttypes.h> header file. */
 /* #undef HAVE_INTTYPES_H */
@@ -73,7 +73,7 @@
 /* #undef HAVE_JASPER */
 
 /* AVIF codec */
-/* #undef HAVE_AVIF */
+#define HAVE_AVIF
 
 /* IJG JPEG codec */
 #define HAVE_JPEG
@@ -119,7 +119,7 @@
 #define HAVE_PTHREADS_PF
 
 /* Intel Threading Building Blocks */
-#define HAVE_TBB
+/* #undef HAVE_TBB */
 
 /* Ste||ar Group High Performance ParallelX */
 /* #undef HAVE_HPX */
@@ -138,7 +138,7 @@
 #define HAVE_VA_INTEL
 
 /* Lapack */
-#define HAVE_LAPACK
+/* #undef HAVE_LAPACK */
 
 /* Library was compiled with functions instrumentation */
 /* #undef ENABLE_INSTRUMENTATION */
