@@ -14,9 +14,13 @@
 #include "opencv2/rgbd/kinfu.hpp"
 #include "opencv2/rgbd/dynafu.hpp"
 #include "opencv2/rgbd/large_kinfu.hpp"
+#include "opencv2/rgbd/detail/pose_graph.hpp"
+#include "opencv2/rgbd/colored_kinfu.hpp"
 
 
 /** @defgroup rgbd RGB-Depth Processing
+
+@ref kinfu_icp
 */
 
 #endif
